@@ -97,7 +97,7 @@ def GBM_REGRESSOR(X_train, X_test, y_train, user_params, verbose):
 
     parameters = {'loss':'ls', 'learning_rate':0.1, 'n_estimators':100, 'subsample':1.0, 'criterion':'friedman_mse', 
                   'min_samples_split':2, 'min_samples_leaf':1, 'min_weight_fraction_leaf':0.0, 'max_depth':3, 
-                  'min_impurity_decrease':0.0, 'min_impurity_split':None, 'init':None, 'random_state':None, 
+                  'min_impurity_decrease':0.0, 'init':None, 'random_state':None, 
                   'max_features':None, 'alpha':0.9, 'verbose':0, 'max_leaf_nodes':None, 'warm_start':False, 
                   'validation_fraction':0.1, 'n_iter_no_change':None, 'tol':0.0001, 'ccp_alpha':0.0}
                     
@@ -239,7 +239,7 @@ def GBM_CLASSIFIER(X_train, X_test, y_train, user_params, verbose):
 
     parameters = {'loss':'deviance', 'learning_rate':0.1, 'n_estimators':100, 'subsample':1.0, 'criterion':'friedman_mse',
                   'min_samples_split':2, 'min_samples_leaf':1, 'min_weight_fraction_leaf':0.0, 'max_depth':3, 'min_impurity_decrease':0.0,
-                  'min_impurity_split':None, 'init':None, 'random_state':1, 'max_features':None, 'verbose':0, 'max_leaf_nodes':None,
+                  'init':None, 'random_state':1, 'max_features':None, 'verbose':0, 'max_leaf_nodes':None,
                   'warm_start':False, 'validation_fraction':0.1, 'n_iter_no_change':None, 'tol':0.0001, 'ccp_alpha':0.0}
     
     if user_params is not None:
